@@ -1,5 +1,5 @@
-/* $Id: frap-icon-entry.c 24140 2006-12-19 19:36:18Z jasper $ */
-/*-
+/* $Id: frap-icon-entry.c 29078 2009-01-02 13:21:47Z nick $
+ *
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -47,8 +47,6 @@ enum
 
 
 
-static void     frap_icon_entry_class_init          (FrapIconEntryClass *klass);
-static void     frap_icon_entry_init                (FrapIconEntry      *icon_entry);
 static void     frap_icon_entry_finalize            (GObject            *object);
 static void     frap_icon_entry_get_property        (GObject            *object,
                                                      guint               prop_id,
